@@ -1,6 +1,7 @@
-from .core import Module, ModulePriorities
+from .core import Injectable, Module, ModulePriorities
 
 __all__ = (
+    "Injectable",
     "Module",
     "ModulePriorities",
     "default_module",
@@ -16,9 +17,7 @@ default_module = Module(f"{__name__}:default_module")
 
 get_instance = default_module.get_instance
 get_lazy_instance = default_module.get_lazy_instance
-
 inject = default_module.inject
 injectable = default_module.injectable
-singleton = default_module.singleton
-
 set_constant = default_module.set_constant
+singleton = default_module.singleton
